# Changelog

## Unreleased

## [5.3.0.alpha] - 2018-05-06

- Added [undocumented] fetcher extension interface

## [5.2.0] - 2018-05-06

## Changed
- `kibitzr firefox` now prompts for Return to save profile
- Firefox profile directory path moved to capabilities in the new version

## [5.1.1] - 2018-04-19

## Added
- `kibitzr stash` command to show stash contents.

## [5.1.0] - 2018-04-10

## Added
- kibitzr clean command to delete changes history (#13 thanks to @attilanagy)
- Jinja filters: int and float

## [5.0.0] - 2017-12-16
## Changed
- Dropped support for Firefox < 56 (using -headless instead of XVFB)

## [4.0.10] - 2017-08-28
## Changed
- Fix #47: Xpath transform encodes content to UTF-8 before parsing (X|HT)ML

## [4.0.9] - 2017-08-21
## Fixed
- Allow SMTP without authentication
## Changed
- Use local SMTP server by default

## [4.0.8] - 2017-08-02
## Fixed
- Fixed xpath selector transform

## [4.0.7] - 2017-06-29
## Fixed
- Fixed interruption exit code (1)

## [4.0.6] - 2017-06-28
## Fixed
- Exit(2) when receiving SIGTERM/SIGINT

## [4.0.5] - 2017-06-14
## Fixed
- Exit(1) Kibitzr when Firefox goes funny business

## [4.0.4] - 2017-06-07
## Changed
- Firefox fetcher: Implicitly wait 2 seconds for selects
- Firefox fetcher: Resize window before each fetch
## Fixed
- bash transform: Skip execution for empty content

## [4.0.3] - 2017-05-25
## Added
- Changes style "new" - show only current content if it changed
## Fixed
- text filter in Jinja templates
- Adapted list of requirements for Windows

## [4.0.2] - 2017-05-21
## Added
- Explicit telegram imprinting
## Fixed
- Dynamically import only what's needed in checks
- Better Windows support
- Support for non-ascii URLs

## [4.0.1] - 2017-05-10
## Added
- Credentials extensions through entry points (for kibitzr-keyring).

## [4.0.0] - 2017-05-08
## Added
- `kibitzr init` - create sample configuration files
## Changed
- Changed kibitzr CLI commands structure (`kibitzr run` instead of `kibitzr`)

## [3.1.8] - 2017-05-08
## Fixed
- Unspecified period caused error (introduced in 3.1.4)

## [3.1.7] - 2017-05-06
## Fixed
- Gracefull shutdown on SIGTERM (as on SIGINT)

## [3.1.6] - 2017-05-05
## Fixed
- Jinja transform
## Added
- CHANGELOG to PyPI page

## [3.1.4] - 2017-05-04
## Changed
- human-readable period

## [3.1.3] - 2017-05-01
## Fixed
- Bash and Python transforms parameter (dis)order
- Skip Bash transform if input is empty
## Changed
- Requests fetcher uses caching

## [3.1.0] - 2017-05-01
## Added
- Jinja transform
## Removed
- cut and sort transforms (superseded by bash)

## [3.0.11] - 2017-04-30
## Added
- Browser form filling shorthand

## [3.0.10] - 2017-04-29
## Added
- Bash transform
## Fixed
- jq transform input encoding

## [3.0.9] - 2017-04-25
## Fixed
- Firefox fetcher: retry 3 times on stale element exception
- Persistent Firefox: Ignore all exceptions when closing

## [3.0.8] - 2017-04-24
## Added
- Transformer css-all selector which returns all elements instead of first
- Python transformer
## Changed
- Missing check name autopopulated from URL or autogenerated

## [3.0.7] - 2017-04-19
## Added
- Zapier notifier

## [3.0.6] - 2017-04-19
## Added
- Telegram notifier

## [3.0.3] - 2017-04-18
## Added
- Persistent firefox profile [undocumented]

## [3.0.2] - 2017-04-18
## Added
- Short form for SMTP notifier #11
## Fixed
- Weird BS4 misbehaviour in CSS selector

## [3.0.1] - 2017-04-07
## Fixed
- Exit if no checks defined
- Better credentials reloading

## [3.0.0] - 2017-04-04
## Changed
- Switched to selenium >3 and Firefox >48

## [2.7.4] - 2017-04-01
## Changed
- Closing FireFox tab after it was fetched to reduce idle CPU

## [2.7.3] - 2017-03-31
## Added
- Started CHANGELOG
- script.python fetcher
